@@ -1,5 +1,5 @@
 /* BEGIN_COMMON_COPYRIGHT_HEADER
- * (c)GPL2
+ * (c)LGPL2+
  *
  * Razor - a lightweight, Qt based, desktop toolset
  * http://razor-qt.org
@@ -12,19 +12,18 @@
  * This program or library is free software; you can redistribute it
  * and/or modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 3 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
- *
+
  * You should have received a copy of the GNU Lesser General
  * Public License along with this library; if not, write to the
  * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  * Boston, MA 02110-1301 USA
  *
- *
  * END_COMMON_COPYRIGHT_HEADER */
 
 
@@ -80,13 +79,7 @@ const XfitMan&  xfitMan()
  */
 XfitMan::XfitMan()
 {
-#if 0
-    getAtoms();
-#endif
     root = QX11Info::appRootWindow();
-#if 0
-    screencount = ScreenCount(QX11Info::display());
-#endif
 }
 
 /**
@@ -148,16 +141,6 @@ Window XfitMan::getActiveAppWindow() const
     return 0;
 }
 
-#if 0
-/**
- * @brief this makes the wm send Windowevents to us which normally do not belong to zs
- */
-void XfitMan::setEventRoute() const
-{
-    XSelectInput(QX11Info::display(), root, StructureNotifyMask | SubstructureNotifyMask);
-}
-#endif
-
 /**
  * @brief returns the window that currently has inputfocus
  */
@@ -285,7 +268,7 @@ XfitMan::~XfitMan()
  */
 
 //i got the idea for this from taskbar-plugin of LXPanel - so credits fly out :)
-QString XfitMan::getName(Window _wid) const
+QString XfitMan::getWindowTitle(Window _wid) const
 {
     QString name = "";
     //first try the modern net-wm ones
@@ -301,18 +284,22 @@ QString XfitMan::getName(Window _wid) const
     }
 
     if (name.isEmpty())
+    {
         if (getWindowProperty(_wid, atom("_NET_WM_NAME"), utf8Atom, &length, &data))
         {
             name = QString::fromUtf8((char*) data);
             XFree(data);
         }
+    }
 
     if (name.isEmpty())
+    {
         if (getWindowProperty(_wid, atom("XA_WM_NAME"), XA_STRING, &length, &data))
         {
             name = (char*) data;
             XFree(data);
         }
+    }
 
     if (name.isEmpty())
     {
@@ -321,23 +308,39 @@ QString XfitMan::getName(Window _wid) const
         if (0 != ok) XFree(data);
     }
 
+    if (name.isEmpty())
+    {
+        XTextProperty prop;
+        if (XGetWMName(QX11Info::display(), _wid, &prop))
+        {
+            name = QString::fromUtf8((char*) prop.value);
+            XFree(prop.value);
+        }
+    }
+
     return name;
 }
 
-
-#if 0
-/**
- * @brief this add(1) / removes (0) / toggles (2) the _NET_WM_STATE_XXXX flag for a
- *  specified window
- * @param[in] _wid windowId for the action
- * @param[in] _atomcode the QString-code for atomMap - state
- * @param[in] _action the action to do (add 1, remove 0, toggle 2)
- */
-void XfitMan::setClientStateFlag(Window _wid, const QString & _atomcode, int _action) const
+QString XfitMan::getApplicationName(Window _wid) const
 {
-    clientMessage(_wid, atomMap["net_wm_state"],_action,atomMap[_atomcode],0,0,0);
+    XClassHint hint;
+    QString ret;
+
+    if (XGetClassHint(QX11Info::display(), _wid, &hint))
+    {
+        if (hint.res_name)
+        {
+            ret = hint.res_name;
+            XFree(hint.res_name);
+        }
+        if (hint.res_class)
+        {
+            XFree(hint.res_class);
+        }
+    }
+
+    return ret;
 }
-#endif
 
 /**
  * @brief sends a clientmessage to a window
@@ -367,13 +370,6 @@ int XfitMan::clientMessage(Window _wid, Atom _msg,
         return EXIT_FAILURE;
 }
 
-#if 0
-void XfitMan::mapRaised(Window _wid) const
-{
-    XMapRaised(QX11Info::display(), _wid);
-}
-#endif
-
 
 /***********************************************
 
@@ -449,14 +445,6 @@ bool XfitMan::isHidden(Window _wid) const
     return getWindowState(_wid).Hidden;
 }
 
-#if 0
-bool XfitMan::requiresAttention(Window _wid) const
-{
-    return getWindowState(_wid).Attention;
-}
-#endif
-
-
 Atom XfitMan::atom(const char* atomName)
 {
     static QHash<QString, Atom> hash;
@@ -469,48 +457,6 @@ Atom XfitMan::atom(const char* atomName)
     return atom;
 }
 
-#if 0
-/**
- * @brief gets the used atoms into a QMap for further usage
- */
-void XfitMan::getAtoms() const
-{
-    atomMap["net_wm_strut"] = XInternAtom(QX11Info::display(), "_NET_WM_STRUT", False);
-    atomMap["net_wm_strut_partial"] = XInternAtom(QX11Info::display(), "_NET_WM_STRUT_PARTIAL", False);
-    atomMap["net_client_list"] = XInternAtom(QX11Info::display(), "_NET_CLIENT_LIST", False);
-    atomMap["net_wm_visible_name"] =XInternAtom(QX11Info::display(), "_NET_WM_VISIBLE_NAME", False);
-    atomMap["net_wm_name"] =XInternAtom(QX11Info::display(), "_NET_WM_NAME", False);
-    atomMap["xa_wm_name"] =XInternAtom(QX11Info::display(), "XA_WM_NAME", False);
-    atomMap["utf8"] = XInternAtom(QX11Info::display(), "UTF8_STRING", False);
-    atomMap["net_wm_icon"] = XInternAtom(QX11Info::display(), "_NET_WM_ICON", False);
-    atomMap["net_wm_state_hidden"] = XInternAtom(QX11Info::display(), "_NET_WM_STATE_HIDDEN", False);
-    atomMap["net_wm_state_fullscreen"] = XInternAtom(QX11Info::display(), "_NET_WM_STATE_FULLSCREEN", False);
-    atomMap["net_wm_state"] = XInternAtom(QX11Info::display(), "_NET_WM_STATE", False);
-    atomMap["net_current_desktop"] = XInternAtom(QX11Info::display(), "_NET_CURRENT_DESKTOP", False);
-    atomMap["net_wm_desktop"] = XInternAtom(QX11Info::display(),"_NET_WM_DESKTOP", False);
-    atomMap["net_active_window"] = XInternAtom(QX11Info::display(), "_NET_ACTIVE_WINDOW", False);
-    atomMap["_win_workspace"] = XInternAtom(QX11Info::display(), "_WIN_WORKSPACE", False);
-    atomMap["net_number_of_desktops"] = XInternAtom(QX11Info::display(), "_NET_NUMBER_OF_DESKTOPS", False);
-
-    atomMap["net_wm_window_type"] = XInternAtom(QX11Info::display(), "_NET_WM_WINDOW_TYPE", False);
-    atomMap["net_wm_window_type_normal"] = XInternAtom(QX11Info::display(), "_NET_WM_WINDOW_TYPE_NORMAL", False);
-    atomMap["net_wm_window_type_desktop"] = XInternAtom(QX11Info::display(), "_NET_WM_WINDOW_TYPE_DESKTOP", False);
-    atomMap["net_wm_window_type_dock"] = XInternAtom(QX11Info::display(), "_NET_WM_WINDOW_TYPE_DOCK", False);
-    atomMap["net_wm_window_type_splash"] = XInternAtom(QX11Info::display(), "_NET_WM_WINDOW_TYPE_SPLASH", False);
-    atomMap["kde_net_wm_window_type_override"] = XInternAtom(QX11Info::display(), "_KDE_NET_WM_WINDOW_TYPE_OVERRIDE", False);
-
-    char atomname[20] = {0};
-    qsnprintf(atomname, 20, "_NET_SYSTEM_TRAY_S%d", DefaultScreen(QX11Info::display()));
-    atomMap["net_system_tray"] = XInternAtom(QX11Info::display(), atomname, False);
-    atomMap["net_system_tray_opcode"] = XInternAtom(QX11Info::display(), "_NET_SYSTEM_TRAY_OPCODE", False);
-    atomMap["net_manager"] = XInternAtom(QX11Info::display(), "MANAGER", False);
-    atomMap["net_message_data"] = XInternAtom(QX11Info::display(), "_NET_SYSTEM_TRAY_MESSAGE_DATA", False);
-    atomMap["xrootpmap"] = XInternAtom(QX11Info::display(), "_XROOTPMAP_ID", False);
-    atomMap["esetroot"] = XInternAtom(QX11Info::display(), "ESETROOT_PMAP_ID", False);
-    atomMap["net_wm_window_demands_attention"] = XInternAtom(QX11Info::display(), "_NET_WM_STATE_DEMANDS_ATTENTION", False);
-}
-#endif
-
 AtomList XfitMan::getWindowType(Window window) const
 {
     AtomList result;
@@ -541,8 +487,16 @@ bool XfitMan::acceptWindow(Window window) const
                     << atom("_NET_WM_WINDOW_TYPE_SPLASH")
                     << atom("_NET_WM_WINDOW_TYPE_TOOLBAR")
                     << atom("_NET_WM_WINDOW_TYPE_MENU")
-                    << atom("_KDE_NET_WM_WINDOW_TYPE_OVERRIDE");
-                    
+                    // for qlipper - using qpopup as a main window
+                    << atom("_NET_WM_WINDOW_TYPE_POPUP_MENU");
+        // issue #284: qmmp its not registered in window list panel
+        // qmmp has _KDE_NET_WM_WINDOW_TYPE_OVERRIDE in its
+        // _NET_WM_WINDOW_TYPE(ATOM) = _KDE_NET_WM_WINDOW_TYPE_OVERRIDE, _NET_WM_WINDOW_TYPE_NORMAL
+        // Let's expect that _KDE_NET_WM_WINDOW_TYPE_OVERRIDE can be set for
+        // regular windows too. If it should be hidden we should expect
+        // one of atoms listed above.
+//                    << atom("_KDE_NET_WM_WINDOW_TYPE_OVERRIDE");
+
         foreach (Atom i, ignoreList)
         {
             if (types.contains(i))
@@ -571,7 +525,7 @@ bool XfitMan::acceptWindow(Window window) const
 /**
  * @brief gets a client list
  */
-QList<Window> XfitMan::getClientList() const
+WindowList XfitMan::getClientList() const
 {
     //initialize the parameters for the XGetWindowProperty call
     unsigned long length, *data;
@@ -773,34 +727,6 @@ void XfitMan::setActiveDesktop(int _desktop) const
     clientMessage(root, atom("_NET_CURRENT_DESKTOP"), (unsigned long) _desktop,0,0,0,0);
 }
 
-#if 0
-/**
- * @brief this sets a window as selection owner for a specified atom - checks for success then sends the clientmessage
- */
-void XfitMan::setSelectionOwner(Window _wid, const QString & _selection, const QString & _manager) const
-{
-    if (getSelectionOwner(_selection))
-    {
-        qWarning() << "Another tray started";
-        return;
-    }
-
-    XSetSelectionOwner(QX11Info::display(), atomMap.value(_selection), _wid, CurrentTime);
-    if (getSelectionOwner(_selection)== _wid)
-        clientMessage(QApplication::desktop()->winId(),atomMap.value(_manager),CurrentTime,atomMap.value(_selection),_wid,0,0);
-}
-#endif
-
-#if 0
-/**
- * @brief returns the owning window of selection _selection
- */
-Window XfitMan::getSelectionOwner(const QString & _selection) const
-{
-    return XGetSelectionOwner(QX11Info::display(), atomMap.value(_selection));
-}
-#endif
-
 /**
  * @brief sets net_wm_strut_partial = our reserved panelspace for the mainbar!
  */
@@ -815,7 +741,7 @@ void XfitMan::setStrut(Window _wid,
                        ) const
 {
     //qDebug() << "XfitMan: Trying to set STRUT_PARTIAL for panel!";
-    //prepare strutsize
+    unsigned long desstrut[12];
     memset(desstrut,0,sizeof(desstrut));
     //prepare the array
     //it has format:
@@ -847,16 +773,6 @@ void XfitMan::setStrut(Window _wid,
                     XA_CARDINAL, 32, PropModeReplace, (unsigned char*) desstrut, 4);
 }
 
-#if 0
-/**
- * @brief this unsets the strut set for panel
- */
-void XfitMan::unsetStrut(Window _wid) const
-{
-    XDeleteProperty(QX11Info::display(), _wid, atom("_NET_WM_STRUT"));
-    XDeleteProperty(QX11Info::display(), _wid, atom("_NET_WM_STRUT_PARTIAL"));
-}
-#endif
 
 #ifdef DEBUG
 /************************************************
@@ -885,7 +801,7 @@ QString XfitMan::debugWindow(Window wnd)
     else
         typeStr ="ERROR";
 
-    return QString("[%1] %2 %3").arg(wnd,8, 16).arg(xfitMan().getName(wnd)).arg(typeStr);
+    return QString("[%1] %2 %3").arg(wnd,8, 16).arg(xfitMan().getWindowTitle(wnd)).arg(typeStr);
 }
 #endif
 
