@@ -1,15 +1,11 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.0" language="da_DK">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="da_DK" version="2.0">
 <context>
     <name>IconThemeConfig</name>
     <message>
-        <location filename="../mainwindow.ui" line="14"/>
         <source>Razor Appearance Configuration</source>
         <translation>Razor Indstillinger for Udseende</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="26"/>
         <source>Icons Theme</source>
         <translation>Ikontema</translation>
     </message>
@@ -17,14 +13,23 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../main.cpp" line="44"/>
         <source>Razor Appearance Configuration</source>
         <translation>Razor Indstillinger for Udseende</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="46"/>
         <source>Icons Theme</source>
         <translation>Ikontema</translation>
     </message>
+    <message>
+        <source>Razor Theme</source>
+        <translation>Razor Tema</translation>
+    </message>
 </context>
-</TS>
+<context>
+    <name>RazorThemeConfig</name>
+    <message>
+        <source>Razor Theme</source>
+        <translation>Razor Tema</translation>
+    </message>
+</context>
+</TS>
\ No newline at end of file
