@@ -25,19 +25,15 @@
  *
  * END_COMMON_COPYRIGHT_HEADER */
 
-#include <QtGui/QApplication>
-#include <QtGui/QIcon>
-
-#include <qtxdg/xdgicon.h>
-#include <razorqt/razorsettings.h>
+#include <razorqt/razorapplication.h>
+#include "razortranslate.h"
 #include "mainwindow.h"
 
 
 int main(int argc, char **argv)
 {
-    QApplication app(argc, argv);
-    XdgIcon::setThemeName(RazorSettings::globalSettings()->value("icon_theme").toString());
-    app.setWindowIcon(QIcon(QString(SHARE_DIR) + "/graphics/razor_logo.png"));
+    RazorApplication app(argc, argv);
+    TRANSLATE_APP;
     
     RazorConfig::MainWindow w;
     w.show();
