@@ -25,20 +25,19 @@
  *
  * END_COMMON_COPYRIGHT_HEADER */
 
-#include <QtGui/QApplication>
+#include <razorqt/razorapplication.h>
 
 #include <qtxdg/xdgicon.h>
 #include <razorqt/razorsettings.h>
 
 #include "desktopconfigwindow.h"
-
+#include "razortranslate.h"
 
 int main(int argc, char** argv)
 {
     // TODO/FIXME: maybe singleapp?
-    QApplication a(argc, argv);
-    a.setWindowIcon(QIcon(QString(SHARE_DIR) + "/graphics/razor_logo.png"));
-    XdgIcon::setThemeName(RazorSettings::globalSettings()->value("icon_theme").toString());
+    RazorApplication a(argc, argv);
+    TRANSLATE_APP;
 
     DesktopConfigWindow w;
     w.show();
