@@ -1,15 +1,11 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.0" language="cs_CZ">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs_CZ" version="2.0">
 <context>
     <name>ConfigureDialog</name>
     <message>
-        <location filename="../configuredialog.ui" line="14"/>
         <source>Analog clock settings</source>
         <translation>Nastavení ručičkových hodin</translation>
     </message>
     <message>
-        <location filename="../configuredialog.ui" line="23"/>
         <source>Show &amp;seconds hand</source>
         <translation>Ukázat ručičku pro &amp;sekundy</translation>
     </message>
@@ -20,5 +16,9 @@
         <source>Clock</source>
         <translation>Hodiny</translation>
     </message>
+    <message>
+        <source>Clock:</source>
+        <translation>Hodiny:</translation>
+    </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
