@@ -1,15 +1,11 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.0" language="da_DK">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="da_DK" version="2.0">
 <context>
     <name>ConfigureDialog</name>
     <message>
-        <location filename="../configuredialog.ui" line="14"/>
         <source>Analog clock settings</source>
         <translation>Analog urindstillinger</translation>
     </message>
     <message>
-        <location filename="../configuredialog.ui" line="23"/>
         <source>Show &amp;seconds hand</source>
         <translation>Vis &amp;sekundviser</translation>
     </message>
@@ -17,9 +13,12 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../clock.cpp" line="91"/>
         <source>Clock</source>
         <translation>Ur</translation>
     </message>
+    <message>
+        <source>Clock:</source>
+        <translation>Ur:</translation>
+    </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
