@@ -1,25 +1,24 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.0" language="de_DE">
-<context>
-    <name>Clock</name>
-    <message>
-        <location filename="../clock.cpp" line="91"/>
-        <source>Clock</source>
-        <translation>Uhr</translation>
-    </message>
-</context>
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="de_DE" version="2.0">
 <context>
     <name>ConfigureDialog</name>
     <message>
-        <location filename="../configuredialog.ui" line="14"/>
         <source>Analog clock settings</source>
         <translation>Analoge Uhr Einstellungen</translation>
     </message>
     <message>
-        <location filename="../configuredialog.ui" line="23"/>
         <source>Show &amp;seconds hand</source>
         <translation>Zeige &amp;Sekungenzeiger </translation>
     </message>
 </context>
-</TS>
+<context>
+    <name>QObject</name>
+    <message>
+        <source>Clock</source>
+        <translation>Uhr</translation>
+    </message>
+    <message>
+        <source>Clock:</source>
+        <translation>Uhr:</translation>
+    </message>
+</context>
+</TS>
\ No newline at end of file
