@@ -1,15 +1,11 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.0" language="hu_HU">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="hu_HU" version="2.0">
 <context>
     <name>ConfigureDialog</name>
     <message>
-        <location filename="../configuredialog.ui" line="14"/>
         <source>Analog clock settings</source>
         <translation>Az analóg óra beállításai</translation>
     </message>
     <message>
-        <location filename="../configuredialog.ui" line="23"/>
         <source>Show &amp;seconds hand</source>
         <translation>Má&amp;sodpercmutató megjelenítése</translation>
     </message>
@@ -20,5 +16,9 @@
         <source>Clock</source>
         <translation>Óra</translation>
     </message>
+    <message>
+        <source>Clock:</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
