@@ -1,17 +1,13 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.0" language="it_IT">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="it_IT" version="2.0">
 <context>
     <name>ConfigureDialog</name>
     <message>
-        <location filename="../configuredialog.ui" line="14"/>
         <source>Analog clock settings</source>
         <translation>Impostazioni orologio analogico</translation>
     </message>
     <message>
-        <location filename="../configuredialog.ui" line="23"/>
         <source>Show &amp;seconds hand</source>
-        <translation>Mostra &amp;secondi</translation>
+        <translation>Mostra lancetta dei &amp;secondi</translation>
     </message>
 </context>
 <context>
@@ -20,5 +16,9 @@
         <source>Clock</source>
         <translation>Orologio</translation>
     </message>
+    <message>
+        <source>Clock:</source>
+        <translation>Orologio:</translation>
+    </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
