@@ -1,17 +1,13 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.0" language="pl_PL">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="pl_PL" version="2.0">
 <context>
     <name>ConfigureDialog</name>
     <message>
-        <location filename="../configuredialog.ui" line="14"/>
         <source>Analog clock settings</source>
         <translation>Ustawienia zegara analogowego</translation>
     </message>
     <message>
-        <location filename="../configuredialog.ui" line="23"/>
         <source>Show &amp;seconds hand</source>
-        <translation>Pokazuj &amp;sekundy</translation>
+        <translation>Wyświetl &amp;sekundnika</translation>
     </message>
 </context>
 <context>
@@ -20,5 +16,9 @@
         <source>Clock</source>
         <translation>Zegar</translation>
     </message>
+    <message>
+        <source>Clock:</source>
+        <translation>Zegar:</translation>
+    </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
