@@ -1,4 +1,4 @@
-<!DOCTYPE TS><TS>
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="sk_SK" version="2.0">
 <context>
     <name>ConfigureDialog</name>
     <message>
@@ -16,5 +16,9 @@
         <source>Clock</source>
         <translation>Hodiny</translation>
     </message>
+    <message>
+        <source>Clock:</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
