@@ -1,25 +1,24 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.0" language="zh_CN">
-<context>
-    <name>Clock</name>
-    <message>
-        <location filename="../clock.cpp" line="89"/>
-        <source>Clock</source>
-        <translation>时钟</translation>
-    </message>
-</context>
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_CN" version="2.0">
 <context>
     <name>ConfigureDialog</name>
     <message>
-        <location filename="../configuredialog.ui" line="14"/>
         <source>Analog clock settings</source>
         <translation>模拟时钟设置</translation>
     </message>
     <message>
-        <location filename="../configuredialog.ui" line="23"/>
         <source>Show &amp;seconds hand</source>
         <translation>显示&amp;秒针</translation>
     </message>
 </context>
-</TS>
+<context>
+    <name>QObject</name>
+    <message>
+        <source>Clock</source>
+        <translation>时钟</translation>
+    </message>
+    <message>
+        <source>Clock:</source>
+        <translation>时钟：</translation>
+    </message>
+</context>
+</TS>
\ No newline at end of file
