@@ -28,6 +28,7 @@
 
 #include "razorpanel.h"
 #include "razorpanel_p.h"
+#include "razorpanellimits.h"
 #include "razorpanelplugin.h"
 #include "razorpanelapplication.h"
 #include "razorpanellayout.h"
@@ -35,40 +36,20 @@
 #include <razorqt/addplugindialog/addplugindialog.h>
 #include <razorqt/razorsettings.h>
 #include <razorqt/razorplugininfo.h>
+#include <razorqt/razorconfigdialog.h>
 
-#include <QtCore/QString>
 #include <QtCore/QDebug>
-#include <QtCore/QLocale>
-#include <QtCore/QTranslator>
-#include <QtGui/QApplication>
+#include <QtCore/QLibrary>
 #include <QtGui/QDesktopWidget>
-#include <QtCore/QRect>
 #include <QtGui/QMenu>
 #include <QtGui/QContextMenuEvent>
-#include <QtCore/QFile>
-#include <QtGui/QAction>
-#include <QtGui/QActionGroup>
-#include <QtGui/QStyle>
-#include <QtCore/QFileInfo>
-#include <QtCore/QLibrary>
-#include <QtGui/QSpacerItem>
 
 #include <qtxdg/xdgicon.h>
+
 #include <razorqt/xfitman.h>
 #include <qtxdg/xdgdirs.h>
-
-#define CFG_PANEL_GROUP     "panel"
-
-#define CFG_KEY_SCREENNUM   "desktop"
-#define CFG_KEY_POSITION    "position"
-#define CFG_KEY_PLUGINS     "plugins"
-#define CFG_KEY_HEIGHT      "height"
-#define CFG_KEY_WIDTH       "width"
-#define CFG_KEY_PERCENT     "width-percent"
-#define CFG_KEY_ALIGNMENT   "alignment"
-
-
-#define CFG_FULLKEY_PLUGINS "panel/plugins"
+#include <QtGui/QWidgetAction>
+#include <QtGui/QToolButton>
 
 
 
@@ -77,7 +58,7 @@
  String is one of "Top", "Left", "Bottom", "Right", string is not case sensitive.
  If the string is not correct, returns defaultValue.
  ************************************************/
-RazorPanel::Position strToPosition(const QString& str, RazorPanel::Position defaultValue)
+RazorPanel::Position RazorPanelPrivate::strToPosition(const QString& str, RazorPanel::Position defaultValue)
 {
     if (str.toUpper() == "TOP")    return RazorPanel::PositionTop;
     if (str.toUpper() == "LEFT")   return RazorPanel::PositionLeft;
@@ -90,7 +71,7 @@ RazorPanel::Position strToPosition(const QString& str, RazorPanel::Position defa
 /************************************************
  Return  string representation of the position
  ************************************************/
-QString positionToStr(RazorPanel::Position position)
+QString RazorPanelPrivate::positionToStr(RazorPanel::Position position)
 {
     switch (position)
     {
@@ -117,6 +98,7 @@ RazorPanel::RazorPanel(QWidget *parent) :
     setWindowFlags(Qt::FramelessWindowHint | Qt::WindowStaysOnTopHint);
     setAttribute(Qt::WA_X11NetWmWindowTypeDock);
     setAttribute(Qt::WA_AlwaysShowToolTips);
+    setWindowTitle("Razor Panel");
 
     setObjectName("RazorPanel");
 }
@@ -149,8 +131,8 @@ RazorPanelPrivate::RazorPanelPrivate(RazorPanel* parent):
     connect(QApplication::desktop(), SIGNAL(screenCountChanged(int)), this, SLOT(screensChangeds()));
     //connect(QApplication::desktop(), SIGNAL(workAreaResized(int)), this, SLOT(screensChangeds()));
 
-    XdgIcon::setThemeName(RazorSettings::globalSettings()->value("icon_theme").toString());
-    connect(RazorSettings::globalSettings(), SIGNAL(settigsChanged()), q_ptr, SLOT(update()));
+    connect(RazorSettings::globalSettings(), SIGNAL(settingsChanged()), q_ptr, SLOT(update()));
+    connect(razorApp, SIGNAL(themeChanged()), this, SLOT(realign()));
 }
 
 
@@ -162,7 +144,7 @@ void RazorPanelPrivate::screensChangeds()
     if (! canPlacedOn(mScreenNum, mPosition))
         mScreenNum = findAvailableScreen(mPosition);
 
-    realign();
+    reposition();
 }
 
 
@@ -176,17 +158,18 @@ void RazorPanelPrivate::init()
     mSettings->beginGroup(CFG_PANEL_GROUP);
     mPosition = strToPosition(mSettings->value(CFG_KEY_POSITION).toString(), RazorPanel::PositionBottom);
     mScreenNum = mSettings->value(CFG_KEY_SCREENNUM, QApplication::desktop()->primaryScreen()).toInt();
-    mHeight = mSettings->value(CFG_KEY_HEIGHT, q->sizeHint().height()).toInt();
+    mHeight = mSettings->value(CFG_KEY_HEIGHT, PANEL_DEFAULT_SIZE).toInt();
     mAlignment = RazorPanel::Alignment(mSettings->value(CFG_KEY_ALIGNMENT, 0).toInt());
     mWidthInPercents = mSettings->value(CFG_KEY_PERCENT, true).toBool();
     mWidth = mSettings->value(CFG_KEY_WIDTH, 100).toInt();
+    mUseThemeSize = mSettings->value(CFG_KEY_AUTOSIZE, true).toBool();
     mSettings->endGroup();
 
     q->setLayout(mLayout);
 
-    realign();
     loadPlugins();
-    reTheme();
+    updatePluginsMinSize();
+    reposition();
 }
 
 
@@ -226,8 +209,6 @@ void RazorPanelPrivate::saveSettings()
     }
 
     mSettings->beginGroup(CFG_PANEL_GROUP);
-    mSettings->setValue(CFG_KEY_SCREENNUM, mScreenNum);
-    mSettings->setValue(CFG_KEY_POSITION, positionToStr(mPosition));
 
     QStringList pluginsStr;
     for (int i=0; i<mLayout->count(); ++i)
@@ -345,17 +326,6 @@ RazorPanelPlugin* RazorPanelPrivate::loadPlugin(const RazorPluginInfo& pluginInf
 }
 
 
-/************************************************
-
- ************************************************/
-void RazorPanelPrivate::reTheme()
-{
-    qApp->setStyleSheet(razorTheme->qss("panel"));
-    realign();
-}
-
-
-
 /************************************************
 
  ************************************************/
@@ -365,26 +335,16 @@ void RazorPanelPrivate::realign()
     /*
     qDebug() << "Realign: DesktopNum" << mScreenNum;
     qDebug() << "Realign: Position  " << positionToStr(mPosition);
-    qDebug() << "Realign: Theme     " << mTheme;
+    //qDebug() << "Realign: Theme     " << mTheme;
     qDebug() << "Realign: SizeHint  " << q->sizeHint();
     qDebug() << "Realign: Screen    " << QApplication::desktop()->screenGeometry(mScreenNum);
     */
 
-    foreach (RazorPanelPlugin* plugin, mPlugins)
-    {
-        plugin->updateSizePolicy();
-    }
-
     // Update stylesheet ............
     q->style()->unpolish(q);
     q->style()->polish(q);
     // ..............................
 
-    if (q->isHorizontal())
-        mLayout->setDirection(QBoxLayout::LeftToRight);
-    else
-        mLayout->setDirection(QBoxLayout::TopToBottom);
-
     QRect screen = QApplication::desktop()->screenGeometry(mScreenNum);
     QRect rect;
 
@@ -395,8 +355,10 @@ void RazorPanelPrivate::realign()
         if (mWidthInPercents)
             rect.setWidth(screen.width() * mWidth / 100);
         else
-            rect.setWidth(mWidth);
+            rect.setWidth(mWidth);        
 
+        q->setGeometry(rect);
+        rect = q->geometry();
         // Horiz ....................
         switch (mAlignment)
         {
@@ -428,6 +390,9 @@ void RazorPanelPrivate::realign()
         else
             rect.setHeight(mWidth);
 
+        q->setGeometry(rect);
+        rect = q->geometry();
+
         // Vert .....................
         switch (mAlignment)
         {
@@ -450,7 +415,6 @@ void RazorPanelPrivate::realign()
     }
     q->setGeometry(rect);
 
-
     // Reserve our space on the screen ..........
     XfitMan xf = xfitMan();
     Window wid = q->effectiveWinId();
@@ -505,7 +469,7 @@ void RazorPanelPrivate::realign()
   This function checks, is the panel can be placed on the display
   @displayNum on @position.
  ************************************************/
-bool RazorPanelPrivate::canPlacedOn(int screenNum, RazorPanel::Position position) const
+bool RazorPanelPrivate::canPlacedOn(int screenNum, RazorPanel::Position position)
 {
     QDesktopWidget* dw = QApplication::desktop();
 
@@ -562,41 +526,6 @@ int RazorPanelPrivate::findAvailableScreen(RazorPanel::Position position)
 }
 
 
-/************************************************
-
- ************************************************/
-PositionAction::PositionAction(int displayNum, RazorPanel::Position position, QActionGroup *parent):
-    QAction(parent)
-{
-    if (QApplication::desktop()->screenCount() == 1)
-    {
-        switch (position)
-        {
-            case RazorPanel::PositionTop:    setText(tr("Top of desktop"));      break;
-            case RazorPanel::PositionBottom: setText(tr("Bottom of desktop"));   break;
-            case RazorPanel::PositionLeft:   setText(tr("Left of desktop"));     break;
-            case RazorPanel::PositionRight:  setText(tr("Right of desktop"));    break;
-        }
-    }
-    else
-    {
-        switch (position)
-        {
-        case RazorPanel::PositionTop:    setText(tr("Top of desktop %1").arg(displayNum +1));    break;
-        case RazorPanel::PositionBottom: setText(tr("Bottom of desktop %1").arg(displayNum +1)); break;
-        case RazorPanel::PositionLeft:   setText(tr("Left of desktop %1").arg(displayNum +1));   break;
-        case RazorPanel::PositionRight:  setText(tr("Right of desktop %1").arg(displayNum +1));  break;
-        }
-    }
-
-
-    mPosition = position;
-    mDisplayNum = displayNum;
-    setCheckable(true);
-    parent->addAction(this);
-}
-
-
 /************************************************
 
  ************************************************/
@@ -650,10 +579,17 @@ void RazorPanelPrivate::showConfigPanelDialog()
 {
     Q_Q(RazorPanel);
     QRect screen = QApplication::desktop()->screenGeometry(mScreenNum);
-    ConfigPanelDialog* dlg = new ConfigPanelDialog (mHeight, screen.width(), mSettings, q);
+    RazorConfigDialog* dlg = new RazorConfigDialog(tr("Configure panel"), mSettings, q);
+    ConfigPanelDialog* page = new ConfigPanelDialog (PANEL_DEFAULT_SIZE, screen.width(), mSettings, dlg);
+    page->setSizeLimits(PANEL_MINIMUM_SIZE, PANEL_MAXIMUM_SIZE);
+    dlg->addPage(page, tr("Configure panel"));
+
     dlg->setAttribute(Qt::WA_DeleteOnClose);
-    connect(dlg, SIGNAL(configChanged(int, int, bool, RazorPanel::Alignment)),
-                      SLOT(updateSize(int, int, bool, RazorPanel::Alignment)));
+    connect(dlg, SIGNAL(reset()), page, SLOT(reset()));
+    connect(dlg, SIGNAL(save()), page, SLOT(save()));
+    connect(page, SIGNAL(configChanged(int, int, bool, RazorPanel::Alignment, bool)),
+                      SLOT(updateSize(int, int, bool, RazorPanel::Alignment, bool)));
+    connect(page, SIGNAL(positionChanged(int, RazorPanel::Position)), SLOT(switchPosition(int, RazorPanel::Position)));
     dlg->show();
 }
 
@@ -661,20 +597,59 @@ void RazorPanelPrivate::showConfigPanelDialog()
 /************************************************
 
  ************************************************/
-void RazorPanelPrivate::updateSize(int height, int width, bool percent, RazorPanel::Alignment alignment)
+void RazorPanelPrivate::updateSize(int height, int width, bool percent, RazorPanel::Alignment alignment, bool useThemeSize)
 {
     mHeight = height;
     mWidth = width;
     mWidthInPercents = percent;
-    mAlignment = alignment;
+    mAlignment = alignment;    
+    mUseThemeSize = useThemeSize;
+
+    updatePluginsMinSize();
     realign();
 }
 
+/************************************************
+
+ ************************************************/
+void RazorPanelPrivate::updatePluginsMinSize()
+{
+    Q_Q(RazorPanel);
+    if (mUseThemeSize)
+    {
+        foreach (RazorPanelPlugin *plugin, mPlugins)
+        {
+            plugin->setMinimumSize(QSize(0,0));
+        }
+
+        mHeight = -1;
+    }
+    else
+    {
+        foreach (RazorPanelPlugin *plugin, mPlugins)
+        {
+            plugin->setMinimumSize(QSize(1,1));
+        }
+
+        if (q->isHorizontal())
+        {
+            q->setMaximumHeight(mHeight);
+        }
+        else
+        {
+            q->setMaximumWidth(mHeight);
+        }
+    }
+}
+
+
 /************************************************
 
  ************************************************/
 void RazorPanelPrivate::addPlugin(const RazorPluginInfo &pluginInfo)
 {
+    Q_Q(RazorPanel);
+
     QString sectionName = pluginInfo.id();
     QStringList groups = mSettings->childGroups();
 
@@ -701,6 +676,7 @@ void RazorPanelPrivate::addPlugin(const RazorPluginInfo &pluginInfo)
 
     realign();
     saveSettings();
+    q->adjustSize();
 }
 
 
@@ -711,7 +687,7 @@ void RazorPanel::show()
 {
     Q_D(RazorPanel);
     QWidget::show();
-    d->realign();
+    d->reposition();
     xfitMan().moveWindowToDesktop(this->effectiveWinId(), -1);
 }
 
@@ -725,6 +701,19 @@ RazorPanel::Position RazorPanel::position() const
     return d->position();
 }
 
+RazorPanel::Orientation RazorPanel::orientation() const
+{
+    Q_D(const RazorPanel);
+    if (d->mPosition == RazorPanel::PositionBottom ||
+        d->mPosition == RazorPanel::PositionTop)
+    {
+        return RazorPanel::Horizontal;
+    }
+    else
+    {
+        return RazorPanel::Vertical;
+    }
+}
 
 /************************************************
 
@@ -748,7 +737,7 @@ bool RazorPanel::event(QEvent* e)
     switch (e->type())
     {
         case QEvent::ContextMenu:
-            d->contextMenuEvent(static_cast<QContextMenuEvent*>(e));
+            showPopupMenu();
             break;
 
         case QEvent::Resize:
@@ -765,126 +754,64 @@ bool RazorPanel::event(QEvent* e)
 /************************************************
 
  ************************************************/
-void RazorPanelPrivate::contextMenuEvent(QContextMenuEvent* event)
+void RazorPanel::showPopupMenu(RazorPanelPlugin *plugin)
 {
-    QMenu* menu = popupMenu(0);
+    Q_D(RazorPanel);
 
-    //menu->addSeparator();
-    //QAction* a = menu->addAction(XdgIcon::fromTheme("application-exit"), "Exit");
-    //connect(a, SIGNAL(triggered()), qApp, SLOT(quit()));
+    QList<QMenu*> pluginsMenus;
+    PopupMenu menu(tr("Panel"));
 
-    menu->exec(event->globalPos());
-    delete menu;
-}
+    menu.setIcon(XdgIcon::fromTheme("configure-toolbars"));
 
+    // Plugin Menu ..............................
+    if (plugin)
+    {
+        QMenu *m = plugin->popupMenu();
 
-/************************************************
+        if (m)
+        {
+            menu.addTitle(plugin->windowTitle().replace("&", "&&"));
 
- ************************************************/
-QMenu* RazorPanel::popupMenu(QWidget *parent) const
-{
-    Q_D(const RazorPanel);
-    return d->popupMenu(parent);
-}
+            menu.addActions(m->actions());
+            pluginsMenus << m;
+        }
+    }
 
+    // Panel menu ...............................
 
-/************************************************
+    menu.addTitle(QIcon(), tr("Panel"));
 
- ************************************************/
-QMenu* RazorPanelPrivate::popupMenu(QWidget *parent) const
-{
-    QMenu* menu = new QMenu(tr("Panel"), parent);
-    menu->setIcon(XdgIcon::fromTheme("configure-toolbars"));
-    QAction* a;
+    menu.addAction(tr("Configure panel..."),
+                   d, SLOT(showConfigPanelDialog())
+                  );
+
+    menu.addAction(XdgIcon::fromTheme("preferences-plugin"),
+                   tr("Add plugins ..."),
+                   d, SLOT(showAddPluginDialog())
+                  );
+
+    // Annoying sub-menu:
+//    QMenu* pluginsMenu = menu.addMenu(tr("Plugins"));
+//    foreach (RazorPanelPlugin* p, d->mPlugins)
+//    {
+//        QMenu *m = p->popupMenu();
+//        if (m)
+//        {
+//            pluginsMenu->addMenu(m);
+//            pluginsMenus.append(m);
+//        }
+//    }
 
 #ifdef DEBUG
-    Q_Q(const RazorPanel);
-    menu->addAction("Exit (debug only)", q, SLOT(close()));
+    menu.addSeparator();
+    menu.addAction("Exit (debug only)", this, SLOT(close()));
 #endif
 
-    // Plugins menu .............................
-    QIcon plugIco = XdgIcon::fromTheme("preferences-plugin");
-    QMenu* pluginsMenu = menu->addMenu(plugIco, tr("Plugins"));
-
-    a = pluginsMenu->addAction(tr("Add plugins ..."));
-    connect(a, SIGNAL(triggered()), this, SLOT(showAddPluginDialog()));
-    pluginsMenu->addSeparator();
-
-
-    foreach (RazorPanelPlugin* plugin, mPlugins)
-    {
-        QMenu* m = pluginsMenu->addMenu(plugin->windowTitle());
-
-        a = new PluginAction(plugin, XdgIcon::fromTheme("transform-move"), tr("Move plugin"), m);
-        connect(a, SIGNAL(triggered()), this, SLOT(onMovePlugin()));
-        m->addAction(a);
-
-        if (plugin->flags().testFlag(RazorPanelPlugin::HaveConfigDialog))
-        {
-            a = new PluginAction(plugin, tr("Configure plugin"), m);
-            connect(a, SIGNAL(triggered()), plugin, SLOT(showConfigureDialog()));
-            m->addAction(a);
-        }
-
-        m->addSeparator();
-
-        a = new PluginAction(plugin, tr("Delete plugin"), m);
-        connect(a, SIGNAL(triggered()), this, SLOT(onRemovePlugin()));
-        m->addAction(a);
-    }
-
-
-    // Create Panel menu ********************************************
-    QMenu* positionMenu = menu->addMenu(tr("Show this panel at"));
-    QActionGroup* posGroup = new QActionGroup(menu);
-
-    QDesktopWidget* dw = QApplication::desktop();
-    for (int i=0; i<dw->screenCount(); ++i)
-    {
-        if (canPlacedOn(i, RazorPanel::PositionTop))
-        {
-            a = new PositionAction(i,  RazorPanel::PositionTop, posGroup);
-            a->setChecked(mPosition == RazorPanel::PositionTop && mScreenNum == i);
-            connect(a, SIGNAL(triggered()), this, SLOT(switchPosition()));
-            positionMenu->addAction(a);
-        }
-
-        if (canPlacedOn(i, RazorPanel::PositionBottom))
-        {
-            a = new PositionAction(i, RazorPanel::PositionBottom, posGroup);
-            a->setChecked(mPosition == RazorPanel::PositionBottom && mScreenNum == i);
-            connect(a, SIGNAL(triggered()), this, SLOT(switchPosition()));
-            positionMenu->addAction(a);
-        }
-
-        if (canPlacedOn(i, RazorPanel::PositionLeft))
-        {
-            a = new PositionAction(i, RazorPanel::PositionLeft, posGroup);
-            a->setChecked(mPosition == RazorPanel::PositionLeft && mScreenNum == i);
-            connect(a, SIGNAL(triggered()), this, SLOT(switchPosition()));
-            positionMenu->addAction(a);
-        }
-
-
-        if (canPlacedOn(i, RazorPanel::PositionRight))
-        {
-            a = new PositionAction(i, RazorPanel::PositionRight, posGroup);
-            a->setChecked(mPosition == RazorPanel::PositionRight && mScreenNum == i);
-            connect(a, SIGNAL(triggered()), this, SLOT(switchPosition()));
-            positionMenu->addAction(a);
-        }
-
-        positionMenu->addSeparator();
-    }
-
-    menu->addSeparator();
-    a = menu->addAction(tr("Configure panel"));
-    connect(a, SIGNAL(triggered()), this, SLOT(showConfigPanelDialog()));
-    menu->addAction(a);
-
-    return menu;
+    menu.exec(QCursor::pos());
+    qDeleteAll(pluginsMenus);
 }
 
+
 /************************************************
 
  ************************************************/
@@ -925,6 +852,8 @@ void RazorPanelPrivate::startMoveWidget()
  ************************************************/
 void RazorPanelPrivate::onRemovePlugin()
 {
+    Q_Q(RazorPanel);
+
     RazorPanelPlugin* plugin;
     PluginAction* a = qobject_cast<PluginAction*>(sender());
     if (a)
@@ -942,25 +871,66 @@ void RazorPanelPrivate::onRemovePlugin()
     mPlugins.removeAll(plugin);
     delete plugin;
     saveSettings();
+    q->adjustSize();
 }
 
 
 /************************************************
 
  ************************************************/
-void RazorPanelPrivate::switchPosition()
+void RazorPanelPrivate::switchPosition(int screenNum, RazorPanel::Position position)
 {
-    PositionAction* a = qobject_cast<PositionAction*>(sender());
-    if (!a)
-        return;
+    mPosition = position;
+    mScreenNum = screenNum;
+    reposition();
+}
 
+/************************************************
+
+ ************************************************/
+void RazorPanelPrivate::reposition()
+{
     Q_Q(RazorPanel);
-    mPosition = a->position();
-    mScreenNum = a->displayNum();
-    realign();
+
+    QRect screen = QApplication::desktop()->screenGeometry(mScreenNum);
+
+    if (q->isHorizontal())
+        mLayout->setDirection(QBoxLayout::LeftToRight);
+    else
+        mLayout->setDirection(QBoxLayout::TopToBottom);
+
+    foreach (RazorPanelPlugin* plugin, mPlugins)
+    {
+        plugin->updateSizePolicy();
+    }
+
     emit q->layoutDirectionChanged(q->isHorizontal() ? QBoxLayout::LeftToRight : QBoxLayout::TopToBottom);
     emit q->positionChanged();
-    saveSettings();
+
+    if (q->isHorizontal())
+    {
+        if (!mUseThemeSize)
+        {
+            q->setMaximumSize(screen.width(), mHeight);
+        }
+        else
+        {
+            q->setMaximumWidth(screen.width());
+        }
+    }
+    else
+    {
+        if (!mUseThemeSize)
+        {
+            q->setMaximumSize(mHeight, screen.height());
+        }
+        else
+        {
+            q->setMaximumHeight(screen.height());
+        }
+    }
+
+    realign();
 }
 
 
@@ -982,3 +952,70 @@ void CursorAnimation::updateCurrentValue(const QVariant &value)
 }
 
 
+static const char POPUPMENU_TITLE[] = "POPUP_MENU_TITLE_OBJECT_NAME";
+
+/************************************************
+
+ ************************************************/
+QAction* PopupMenu::addTitle(const QIcon &icon, const QString &text)
+{
+    QAction *buttonAction = new QAction(this);
+    QFont font = buttonAction->font();
+    font.setBold(true);
+    buttonAction->setText(QString(text).replace("&", "&&"));
+    buttonAction->setFont(font);
+    buttonAction->setIcon(icon);
+
+    QWidgetAction *action = new QWidgetAction(this);
+    action->setObjectName(POPUPMENU_TITLE);
+    QToolButton *titleButton = new QToolButton(this);
+    titleButton->installEventFilter(this); // prevent clicks on the title of the menu
+    titleButton->setDefaultAction(buttonAction);
+    titleButton->setDown(true); // prevent hover style changes in some styles
+    titleButton->setCheckable(true);
+    titleButton->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
+    action->setDefaultWidget(titleButton);
+
+    addAction(action);
+    return action;
+}
+
+
+/************************************************
+
+ ************************************************/
+QAction* PopupMenu::addTitle(const QString &text)
+{
+    return addTitle(QIcon(), text);
+}
+
+
+/************************************************
+
+ ************************************************/
+void PopupMenu::keyPressEvent(QKeyEvent* e)
+{
+    if (e->key() == Qt::Key_Up || e->key() == Qt::Key_Down)
+    {
+        QMenu::keyPressEvent(e);
+
+        QWidgetAction *action = qobject_cast<QWidgetAction*>(this->activeAction());
+        QWidgetAction *firstAction = action;
+
+        while (action && action->objectName() == POPUPMENU_TITLE)
+        {
+            this->keyPressEvent(e);
+            action = qobject_cast<QWidgetAction*>(this->activeAction());
+
+            if (firstAction == action) // we looped and only found titles
+            {
+                this->setActiveAction(0);
+                break;
+            }
+        }
+
+        return;
+    }
+
+    QMenu::keyPressEvent(e);
+}
