@@ -1,12 +1,9 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.0" language="de_DE">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="de_DE" version="2.0">
 <context>
     <name>DesktopSwitch</name>
     <message>
-        <location filename="../desktopswitch.cpp" line="80"/>
         <source>Desktop %1</source>
         <translation>Arbeitsfläche %1</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
