@@ -1,4 +1,4 @@
-<!DOCTYPE TS><TS>
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="sk_SK" version="2.0">
 <context>
     <name>DesktopSwitch</name>
     <message>
@@ -6,4 +6,4 @@
         <translation>Plocha %1</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
