@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.0">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="sk_SK" version="2.0">
 <context>
     <name>RazorMainMenu</name>
     <message>
@@ -34,6 +32,14 @@
         <source>...</source>
         <translation>...</translation>
     </message>
+    <message>
+        <source>Keyboard Shortcut</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Click the button to record shortcut:</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>Choose menu file</source>
         <translation>Vybrať súbor menu</translation>
@@ -43,4 +49,4 @@
         <translation>Súbory menu (*.menu)</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
