@@ -4,9 +4,10 @@
  * Razor - a lightweight, Qt based, desktop toolset
  * http://razor-qt.org
  *
- * Copyright: 2010-2011 Razor team
+ * Copyright: 2010-2012 Razor team
  * Authors:
  *   Petr Vanek <petr@scribus.info>
+ *   Kuzma Shapran <kuzma.shapran@gmail.com>
  *
  * This program or library is free software; you can redistribute it
  * and/or modify it under the terms of the GNU Lesser General Public
@@ -28,19 +29,32 @@
 #ifndef QUICKLAUNCHLAYOUT_H
 #define QUICKLAUNCHLAYOUT_H
 
-#include <QBoxLayout>
+#include <QGridLayout>
+#include "razorpanel.h"
 
 class QuickLaunchButton;
 
-class QuickLaunchLayout : public QBoxLayout
+class QuickLaunchLayout : public QGridLayout
 {
     Q_OBJECT
 public:
-    QuickLaunchLayout(QWidget *parent=0);
+    QuickLaunchLayout(QWidget *parent, RazorPanel *panel);
 
+    void addWidget(QuickLaunchButton *b);
+    void removeWidget(QuickLaunchButton *b);
     void swapButtons(QuickLaunchButton * b1, QuickLaunchButton *b2);
+    QuickLaunchButton* buttonAt(int index);
 
-    QList<QuickLaunchButton*> buttons();
+    QList<QuickLaunchButton*> buttons() { return m_buttons; }
+
+    Qt::Orientations expandingDirections() const;
+
+private:
+    RazorPanel *m_panel;
+    QList<QuickLaunchButton*> m_buttons;
+
+private slots:
+    void relayout();
 };
 
 #endif // QUICKLAUNCHLAYOUT_H
