@@ -1,17 +1,28 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.0" language="cs_CZ">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs_CZ" version="2.0">
+<context>
+    <name>QuickLaunchButton</name>
+    <message>
+        <source>Move left</source>
+        <translation>Přesunout vlevo</translation>
+    </message>
+    <message>
+        <source>Move right</source>
+        <translation>Přesunout vpravo</translation>
+    </message>
+    <message>
+        <source>Remove from quicklaunch</source>
+        <translation>Odstranit z rychlého spuštění</translation>
+    </message>
+</context>
 <context>
     <name>RazorQuickLaunch</name>
     <message>
-        <location filename="../razorquicklaunch.cpp" line="161"/>
         <source>Drop Error</source>
         <translation>Problém s upuštěním</translation>
     </message>
     <message>
-        <location filename="../razorquicklaunch.cpp" line="162"/>
         <source>File/URL &apos;%1&apos; cannot be embedded into QuickLaunch for now</source>
         <translation>Soubor/URL &apos;%1&apos; nyní nelze vložit do rychlého spuštění</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
