@@ -1,20 +1,15 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.0" language="da_DK">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="da_DK" version="2.0">
 <context>
     <name>QuickLaunchButton</name>
     <message>
-        <location filename="../quicklaunchbutton.cpp" line="54"/>
         <source>Move left</source>
         <translation>Flyt mod venstre</translation>
     </message>
     <message>
-        <location filename="../quicklaunchbutton.cpp" line="57"/>
         <source>Move right</source>
         <translation>Flyt mod højre</translation>
     </message>
     <message>
-        <location filename="../quicklaunchbutton.cpp" line="61"/>
         <source>Remove from quicklaunch</source>
         <translation>Fjern fra quicklaunch</translation>
     </message>
@@ -22,14 +17,12 @@
 <context>
     <name>RazorQuickLaunch</name>
     <message>
-        <location filename="../razorquicklaunch.cpp" line="176"/>
         <source>Drop Error</source>
         <translation>Træk og slip fejl</translation>
     </message>
     <message>
-        <location filename="../razorquicklaunch.cpp" line="177"/>
         <source>File/URL &apos;%1&apos; cannot be embedded into QuickLaunch for now</source>
         <translation>Fil/URL &apos;%1&apos; kan ikke blive indlejret i QuickLaunch lige nu</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
