@@ -1,20 +1,15 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.0" language="de_DE">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="de_DE" version="2.0">
 <context>
     <name>QuickLaunchButton</name>
     <message>
-        <location filename="../quicklaunchbutton.cpp" line="54"/>
         <source>Move left</source>
         <translation>Nach links bewegen</translation>
     </message>
     <message>
-        <location filename="../quicklaunchbutton.cpp" line="57"/>
         <source>Move right</source>
         <translation>Nach rechts bewegen</translation>
     </message>
     <message>
-        <location filename="../quicklaunchbutton.cpp" line="61"/>
         <source>Remove from quicklaunch</source>
         <translation>Aus dem Schnellstarter löschen</translation>
     </message>
@@ -22,14 +17,12 @@
 <context>
     <name>RazorQuickLaunch</name>
     <message>
-        <location filename="../razorquicklaunch.cpp" line="175"/>
         <source>Drop Error</source>
         <translation>Drop Error</translation>
     </message>
     <message>
-        <location filename="../razorquicklaunch.cpp" line="176"/>
         <source>File/URL &apos;%1&apos; cannot be embedded into QuickLaunch for now</source>
         <translation>Datei/Pfad &apos;%1&apos; kann im moment nicht in den Schnellstarter integriert werden</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
