@@ -1,20 +1,15 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.0" language="hu_HU">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="hu_HU" version="2.0">
 <context>
     <name>QuickLaunchButton</name>
     <message>
-        <location filename="../quicklaunchbutton.cpp" line="53"/>
         <source>Move left</source>
         <translation>Balra</translation>
     </message>
     <message>
-        <location filename="../quicklaunchbutton.cpp" line="56"/>
         <source>Move right</source>
         <translation>Jobbra</translation>
     </message>
     <message>
-        <location filename="../quicklaunchbutton.cpp" line="60"/>
         <source>Remove from quicklaunch</source>
         <translation>Eltávolítás a gyorsindítóról</translation>
     </message>
@@ -22,14 +17,12 @@
 <context>
     <name>RazorQuickLaunch</name>
     <message>
-        <location filename="../razorquicklaunch.cpp" line="174"/>
         <source>Drop Error</source>
         <translation>Ejtési hiba</translation>
     </message>
     <message>
-        <location filename="../razorquicklaunch.cpp" line="175"/>
         <source>File/URL &apos;%1&apos; cannot be embedded into QuickLaunch for now</source>
         <translation>A(z) „%1” fájl vagy URL nem ágyazható be a Gyorsindítóba</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
