@@ -1,35 +1,28 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.0" language="it_IT">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="it_IT" version="2.0">
 <context>
     <name>QuickLaunchButton</name>
     <message>
-        <location filename="../quicklaunchbutton.cpp" line="54"/>
         <source>Move left</source>
         <translation>Sposta a sinistra</translation>
     </message>
     <message>
-        <location filename="../quicklaunchbutton.cpp" line="57"/>
         <source>Move right</source>
         <translation>Sposta a destra</translation>
     </message>
     <message>
-        <location filename="../quicklaunchbutton.cpp" line="61"/>
         <source>Remove from quicklaunch</source>
-        <translation>Rimuovi dal lanciatore</translation>
+        <translation>Rimuovi da Avvio rapido</translation>
     </message>
 </context>
 <context>
     <name>RazorQuickLaunch</name>
     <message>
-        <location filename="../razorquicklaunch.cpp" line="175"/>
         <source>Drop Error</source>
         <translation>Errore di spostamento</translation>
     </message>
     <message>
-        <location filename="../razorquicklaunch.cpp" line="176"/>
         <source>File/URL &apos;%1&apos; cannot be embedded into QuickLaunch for now</source>
-        <translation>Il File posizionato /URL &apos;%1&apos; non può essere posizionato nel lanciatore al momento</translation>
+        <translation>Il file/URL &apos;%1&apos; in questo momento non può essere inserito in Avvio rapido</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
