@@ -1,17 +1,28 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.0" language="pl_PL">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="pl_PL" version="2.0">
+<context>
+    <name>QuickLaunchButton</name>
+    <message>
+        <source>Move left</source>
+        <translation>Przesuń w lewo</translation>
+    </message>
+    <message>
+        <source>Move right</source>
+        <translation>Przesuń w prawo</translation>
+    </message>
+    <message>
+        <source>Remove from quicklaunch</source>
+        <translation>Usuń z paska szybkiego uruchamiania</translation>
+    </message>
+</context>
 <context>
     <name>RazorQuickLaunch</name>
     <message>
-        <location filename="../razorquicklaunch.cpp" line="161"/>
         <source>Drop Error</source>
         <translation>Problem dodawania</translation>
     </message>
     <message>
-        <location filename="../razorquicklaunch.cpp" line="162"/>
         <source>File/URL &apos;%1&apos; cannot be embedded into QuickLaunch for now</source>
         <translation>Plik/URL &apos;%1&apos; nie może zostać umiesczony na pasku szybkiego uruchamiania</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
