@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.0">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="sk_SK" version="2.0">
 <context>
     <name>QuickLaunchButton</name>
     <message>
@@ -27,4 +25,4 @@
         <translation>Súbor/URL „%1“ nateraz nemožno vložiť do rýchleho spustenia</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
