@@ -1,17 +1,28 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.0" language="zh_CN">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_CN" version="2.0">
+<context>
+    <name>QuickLaunchButton</name>
+    <message>
+        <source>Move left</source>
+        <translation>左移</translation>
+    </message>
+    <message>
+        <source>Move right</source>
+        <translation>右移</translation>
+    </message>
+    <message>
+        <source>Remove from quicklaunch</source>
+        <translation>从快速启动删除</translation>
+    </message>
+</context>
 <context>
     <name>RazorQuickLaunch</name>
     <message>
-        <location filename="../razorquicklaunch.cpp" line="161"/>
         <source>Drop Error</source>
         <translation>出现错误</translation>
     </message>
     <message>
-        <location filename="../razorquicklaunch.cpp" line="162"/>
         <source>File/URL &apos;%1&apos; cannot be embedded into QuickLaunch for now</source>
         <translation>文件/URL &apos;%1&apos; 暂时无法被嵌入到快速启动</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
