@@ -1,15 +1,9 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.0">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="sk_SK" version="2.0">
 <context>
     <name>PanelScreenSaver</name>
-    <message>
-        <source>Global keyboard shortcut</source>
-        <translation>Globálna klávesová skratka</translation>
-    </message>
     <message>
         <source>Panel Screensaver Global shorcut: &apos;%1&apos; cannot be registered</source>
         <translation>Globálna klávesová skratka Panelu šetriča: „%1“ nemožno zaregistrovať</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
