@@ -61,6 +61,7 @@ RazorTaskButton::RazorTaskButton(const Window window, QWidget *parent) :
     setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
 
     setMinimumWidth(1);
+    setMinimumHeight(1);
     setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
     setAcceptDrops(true);
 
@@ -68,7 +69,7 @@ RazorTaskButton::RazorTaskButton(const Window window, QWidget *parent) :
     updateIcon();
 
     connect(this, SIGNAL(clicked(bool)), this, SLOT(btnClicked(bool)));
-    connect(this, SIGNAL(toggled(bool)), this, SLOT(checkedChanged(bool)));
+    connect(this, SIGNAL(toggled(bool)), this, SLOT(checkedChanged(bool)));    
 
     XSelectInput(QX11Info::display(), mWindow, EnterWindowMask|FocusChangeMask|PropertyChangeMask|StructureNotifyMask);
 
@@ -95,8 +96,9 @@ RazorTaskButton::~RazorTaskButton()
  ************************************************/
 void RazorTaskButton::updateText()
 {
-    setText(xfitMan().getName(mWindow));
-    setToolTip(text());
+    QString title = xfitMan().getWindowTitle(mWindow);
+    setText(title.replace("&", "&&"));
+    setToolTip(title);
 }
 
 
@@ -122,6 +124,14 @@ void RazorTaskButton::setShowOnlyCurrentDesktopTasks(bool value)
 }
 
 
+/************************************************
+
+ ************************************************/
+void RazorTaskButton::setCloseOnMiddleClick(bool value)
+{
+    mCloseOnMiddleClick = value;
+}
+
 /************************************************
 
  ************************************************/
@@ -150,6 +160,28 @@ void RazorTaskButton::dragLeaveEvent(QDragLeaveEvent *event)
 }
 
 
+/************************************************
+
+ ************************************************/
+void RazorTaskButton::mousePressEvent(QMouseEvent *event)
+{
+    if (event->button() == Qt::LeftButton)
+    {
+        if (this->isChecked())
+        {
+            minimizeApplication();
+        }
+        else
+        {
+            raiseApplication();
+        }
+    }
+    else if (mCloseOnMiddleClick && event->button() == Qt::MidButton)
+    {
+        closeApplication();
+    }
+}
+
 /************************************************
 
  ************************************************/
@@ -569,3 +601,4 @@ int RazorTaskButton::desktopNum() const
 RazorTaskButton* RazorTaskButton::mCheckedBtn = 0;
 
 bool RazorTaskButton::mShowOnlyCurrentDesktopTasks = false;
+bool RazorTaskButton::mCloseOnMiddleClick = true;
