@@ -25,12 +25,13 @@
  *
  * END_COMMON_COPYRIGHT_HEADER */
 
-#include <QApplication>
+#include <razorqt/razorapplication.h>
 
 #include <glib-object.h>
 
 #include <qtxdg/xdgicon.h>
 #include <razorqt/razorsettings.h>
+#include "razortranslate.h"
 
 #include "policykitagent.h"
 
@@ -38,9 +39,8 @@ int main(int argc, char *argv[])
 {
     g_type_init();
 
-    QApplication app(argc, argv);    
-    XdgIcon::setThemeName(RazorSettings::globalSettings()->value("icon_theme").toString());
-    app.setWindowIcon(QIcon(QString(SHARE_DIR) + "/graphics/razor_logo.png"));
+    RazorApplication app(argc, argv);    
+    TRANSLATE_APP;
     
     app.setQuitOnLastWindowClosed(false);
 
