@@ -1,47 +1,37 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.0" language="da_DK">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="da_DK" version="2.0">
 <context>
     <name>Dialog</name>
     <message>
-        <location filename="../dialog.ui" line="20"/>
         <source>Leave</source>
         <translation>Forlad</translation>
     </message>
     <message>
-        <location filename="../dialog.ui" line="26"/>
         <source>What do you want the computer to do?</source>
         <translation>Hvad vil du have computeren til at gøre?</translation>
     </message>
     <message>
-        <location filename="../dialog.ui" line="38"/>
         <source>Logout</source>
         <translation>Log ud</translation>
     </message>
     <message>
-        <location filename="../dialog.ui" line="54"/>
         <source>Reboot</source>
         <translation>Genstart</translation>
     </message>
     <message>
-        <location filename="../dialog.ui" line="70"/>
         <source>Shutdown</source>
         <translation>Luk ned</translation>
     </message>
     <message>
-        <location filename="../dialog.ui" line="80"/>
         <source>Suspend</source>
         <translation>Slumre</translation>
     </message>
     <message>
-        <location filename="../dialog.ui" line="90"/>
         <source>Hibernate</source>
         <translation>Dvale</translation>
     </message>
     <message>
-        <location filename="../dialog.ui" line="115"/>
         <source>Cancel</source>
         <translation>Fortryd</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
