@@ -1,47 +1,37 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.0" language="it_IT">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="it_IT" version="2.0">
 <context>
     <name>Dialog</name>
     <message>
-        <location filename="../dialog.ui" line="20"/>
         <source>Leave</source>
         <translation>Esci</translation>
     </message>
     <message>
-        <location filename="../dialog.ui" line="26"/>
         <source>What do you want the computer to do?</source>
         <translation>Cosa vuoi fare?</translation>
     </message>
     <message>
-        <location filename="../dialog.ui" line="38"/>
         <source>Logout</source>
-        <translation>Esci</translation>
+        <translation>Termina sessione</translation>
     </message>
     <message>
-        <location filename="../dialog.ui" line="54"/>
         <source>Reboot</source>
         <translation>Riavvia</translation>
     </message>
     <message>
-        <location filename="../dialog.ui" line="70"/>
         <source>Shutdown</source>
         <translation>Spegni</translation>
     </message>
     <message>
-        <location filename="../dialog.ui" line="80"/>
         <source>Suspend</source>
         <translation>Sospendi</translation>
     </message>
     <message>
-        <location filename="../dialog.ui" line="90"/>
         <source>Hibernate</source>
         <translation>Iberna</translation>
     </message>
     <message>
-        <location filename="../dialog.ui" line="115"/>
         <source>Cancel</source>
-        <translation>Cancella</translation>
+        <translation>Annulla</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
